km3pipe.db.ParametersContainer
==============================

.. currentmodule:: km3pipe.db

.. autoclass:: ParametersContainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ParametersContainer.__init__
      ~ParametersContainer.get_converter
      ~ParametersContainer.get_parameter
      ~ParametersContainer.oid2name
      ~ParametersContainer.unit
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ParametersContainer.names
   
   